package com.miqporta.cloc.clocWS.BO;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.miqporta.cloc.clocWS.DAO.EscenaDAO;
import com.miqporta.cloc.clocWS.DAO.PeliculaDAO;
import com.miqporta.cloc.clocWS.model.Escena;
import com.miqporta.cloc.clocWS.model.Pelicula;
import com.miqporta.cloc.clocWS.modelVO.EscenaDetalleVO;
import com.miqporta.cloc.clocWS.modelVO.LocalizacionDetalleVO;
import com.miqporta.cloc.clocWS.modelVO.LocalizacionMapaVO;

public class EscenaBO {

	public List<LocalizacionMapaVO> findEscenasByTitulo(String titulo) {
		
		EscenaDAO escenaDAO = new EscenaDAO();
		List<LocalizacionMapaVO> localizacionMapaVOList = new ArrayList<LocalizacionMapaVO>();
		
		List<Escena> escenasList = escenaDAO.findEscenasByTituloPelicula(titulo);
		
		for(Escena escena : escenasList){
			LocalizacionMapaVO localizacionMapaVO = new LocalizacionMapaVO();
			localizacionMapaVO.setEscenaId(escena.getEscenaId());
			localizacionMapaVO.setLatitud(escena.getLatitud());
			localizacionMapaVO.setLongitud(escena.getLongitud());
			localizacionMapaVO.setTituloVO(escena.getPelicula().getTituloVO());
			
			localizacionMapaVOList.add(localizacionMapaVO);
		}
		
		return localizacionMapaVOList;
	}

	public List<LocalizacionMapaVO> findByUbicacionYDistancia(String latitud, String longitud, double distancia) {

		EscenaDAO escenaDAO = new EscenaDAO();
		List<LocalizacionMapaVO> localizacionMapaVOList = new ArrayList<LocalizacionMapaVO>();
		
		List<Escena> escenasList = escenaDAO.findEscenasByUbicacionYDistancia
										(Double.parseDouble(latitud), Double.parseDouble(longitud), distancia);
		
		for(Escena escena : escenasList){
			LocalizacionMapaVO localizacionMapaVO = new LocalizacionMapaVO();
			localizacionMapaVO.setEscenaId(escena.getEscenaId());
			localizacionMapaVO.setLatitud(escena.getLatitud());
			localizacionMapaVO.setLongitud(escena.getLongitud());
			localizacionMapaVO.setTituloVO(escena.getPelicula().getTituloVO());
			
			localizacionMapaVOList.add(localizacionMapaVO);
		}
		
		return localizacionMapaVOList;
	}

	public void anadirUbicacion(LocalizacionDetalleVO localizacionDetalleVO) {
		
		Pelicula pelicula = new Pelicula();
		PeliculaDAO peliculaDAO = new PeliculaDAO();
		
		//Buscamos si existe en la base de datos con el tituloVO y el tituloESP
		pelicula = peliculaDAO.findByExactTitulo(localizacionDetalleVO.getTituloVO());
		
		if(pelicula == null){
			pelicula = peliculaDAO.findByExactTitulo(localizacionDetalleVO.getTituloESP());
		}
		
		//Si no existe se crea una nueva
		if(pelicula == null){
			pelicula = new Pelicula();
			pelicula.setTituloVO(localizacionDetalleVO.getTituloVO());
			pelicula.setTituloESP(localizacionDetalleVO.getTituloESP());
			pelicula.setDataAlta(new Date());
			pelicula.setAnyo(localizacionDetalleVO.getAnyo());
			pelicula.setDirector(localizacionDetalleVO.getDirector());
			peliculaDAO.addPelicula(pelicula);
		}
		
		
		Escena escena = new Escena();
		EscenaDAO escenaDAO = new EscenaDAO();
		EscenaDetalleVO escenaDetalleVO = localizacionDetalleVO.getEscenaDetalleList().get(0);
		escena.setDataAlta(new Date());
		escena.setLatitud(Double.parseDouble(escenaDetalleVO.getLatitud().replaceAll(",", ".")));
		escena.setLongitud(Double.parseDouble(escenaDetalleVO.getLongitud().replaceAll(",", ".")));
		escena.setDescripcion(escenaDetalleVO.getDescripcion());
		escena.setCaptura(escenaDetalleVO.getCaptura());
		escena.setPelicula(pelicula);
		escenaDAO.addEscena(escena);
		
	}

	public LocalizacionDetalleVO findEscenasByEscenaId(String escenaId) {

		EscenaDAO escenaDAO = new EscenaDAO();
		PeliculaDAO peliculaDAO = new PeliculaDAO();
		
		Escena escena = escenaDAO.findbyId(Long.parseLong(escenaId));
		Pelicula pelicula = peliculaDAO.findById(escena.getPelicula().getPeliculaId());
		List<Escena> escenaList = escenaDAO.findEscenasByPeliculaId(pelicula.getPeliculaId());
		
		LocalizacionDetalleVO localizacionDetalleVO = new LocalizacionDetalleVO();
		localizacionDetalleVO.setTituloVO(pelicula.getTituloVO());
		localizacionDetalleVO.setTituloESP(pelicula.getTituloESP());
		localizacionDetalleVO.setAnyo(pelicula.getAnyo());
		localizacionDetalleVO.setDirector(pelicula.getDirector());
		
		List <EscenaDetalleVO> escenaDetalleList = new ArrayList<EscenaDetalleVO>();
		for(Escena e : escenaList){
			EscenaDetalleVO escenaDetalleVO = new EscenaDetalleVO();
			escenaDetalleVO.setEscenaId(String.valueOf(e.getEscenaId()));
			escenaDetalleVO.setLatitud(String.valueOf(e.getLatitud()));
			escenaDetalleVO.setLongitud(String.valueOf(e.getLongitud()));
			escenaDetalleVO.setCaptura(e.getCaptura());
			escenaDetalleVO.setDescripcion(e.getDescripcion());
			escenaDetalleList.add(escenaDetalleVO);
		}
		
		localizacionDetalleVO.setEscenaDetalleList(escenaDetalleList);
		
		return localizacionDetalleVO;
	}

}
