package com.miqporta.cloc.clocWS.DAO;

import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.Session;
import org.hibernate.criterion.Criterion;
import org.hibernate.criterion.Restrictions;

import com.miqporta.cloc.clocWS.model.Escena;
import com.miqporta.cloc.common.HibernateUtil;

public class EscenaDAO {
 
	public Escena findbyId(long escenaId){
		Session session = null;
		Escena escena = new Escena();
		try{
			session = openSession(session); 
			
			Criteria criteria =  session.createCriteria(Escena.class);
			
			criteria.add(Restrictions.eq("escenaId", escenaId));
			
			List<Escena> escenaList = (List<Escena>) criteria.list();
			if(!escenaList.isEmpty()){
				escena = escenaList.get(0);
			}
			
			session.getTransaction().commit();
			
		}catch (Exception e) {
			controlSession( session,  e);
		}
		finally{
			closeSession(session);
		}
		return escena;
	}
	
	public List<Escena> findEscenasByPeliculaId(long peliculaId){
		Session session = null;
		List<Escena> escenaList = null;
		try{
			session = openSession(session); 
			
			Criteria criteria =  session.createCriteria(Escena.class);	
			criteria.add(Restrictions.eq("pelicula.peliculaId", peliculaId));
			
			escenaList = (List<Escena>) criteria.list();
						
			session.getTransaction().commit();

		}catch (Exception e) {
			controlSession( session,  e);
		}
		finally{
			closeSession(session);
		}
	
		return escenaList;		
	}
	
	public List<Escena> findEscenasByTituloPelicula(String titulo){
		Session session = null;
		List<Escena> escenaList = null;
		try{
			session = openSession(session); 
			
			Criteria criteria =  session.createCriteria(Escena.class);	
			
			criteria.createAlias("pelicula", "peli");
			Criterion c1 = Restrictions.ilike("peli.tituloVO", "%"+titulo+"%");
			Criterion c2 = Restrictions.ilike("peli.tituloESP", "%"+titulo+"%");
			criteria.add(Restrictions.or(c1, c2));
			
			
			escenaList = (List<Escena>) criteria.list();
						
			session.getTransaction().commit();

		}catch (Exception e) {
			controlSession( session,  e);
		}
		finally{
			closeSession(session);
		}
	
		return escenaList;		
	}
	
	public List<Escena> findEscenasByUbicacionYDistancia(double latitud, double longitud, double distancia){
		Session session = null;
		List<Escena> escenaList = null;
		try{
			session = openSession(session); 
			
			Criteria criteria =  session.createCriteria(Escena.class);	
			
			criteria.add(Restrictions.between("latitud", latitud - distancia, latitud + distancia));
			criteria.add(Restrictions.between("longitud", longitud - distancia, longitud + distancia));
			
			escenaList = (List<Escena>) criteria.list();
						
			session.getTransaction().commit();

		}catch (Exception e) {
			controlSession( session,  e);
		}
		finally{
			closeSession(session);
		}
	
		return escenaList;		
	}
	
	public void addEscena(Escena escena){
		Session session = null;
		try{
			session = openSession(session); 
			
			session.saveOrUpdate(escena);

			session.getTransaction().commit();

		}catch (Exception e) {
			controlSession( session,  e);
		}
		finally{
			closeSession(session);
		}
	}
	
	private Session openSession(Session session){
		session = HibernateUtil.getSessionFactory().openSession();		
		session.beginTransaction(); 
		
		return session;
	}
	
	private void controlSession(Session session, Exception e){
		try{
			session.getTransaction().rollback();
		}catch(Exception ex){
			ex.printStackTrace();
		}
		e.printStackTrace();
	}
	
	private void closeSession(Session session){
		if(session!=null){
			session.close();
		}
	}
	
	
	
	
}
